==> qtjambi-qml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiQml/QQmlEngineExtensionPlugin_shell.h <==
#ifndef QQMLENGINEEXTENSIONPLUGIN_SHELL_H
#define QQMLENGINEEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlEngineExtensionPlugin_shell : public QQmlEngineExtensionPlugin, public QtJambiShellInterface
{
public:
    QQmlEngineExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QQmlEngineExtensionPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initializeEngine(QQmlEngine* engine0, const char* uri1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlEngineExtensionPlugin_access : public QQmlEngineExtensionPlugin
{
    void __qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1);
};

#endif // QQMLENGINEEXTENSIONPLUGIN_SHELL_H

==> qtjambi-qml-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiQml/QQmlEngineExtensionPlugin_shell.h <==
#ifndef QQMLENGINEEXTENSIONPLUGIN_SHELL_H
#define QQMLENGINEEXTENSIONPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlextensionplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtQml/qqmlengine.h>
#include <QtJambi/RegistryAPI>


class QQmlEngineExtensionPlugin_shell : public QQmlEngineExtensionPlugin, public QtJambiShellInterface
{
public:
    QQmlEngineExtensionPlugin_shell(QObject* parent0 = nullptr);
    ~QQmlEngineExtensionPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initializeEngine(QQmlEngine* engine0, const char* uri1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlEngineExtensionPlugin_access : public QQmlEngineExtensionPlugin
{
    void __qt_initializeEngine_QQmlEngine_ptr_const_char_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID engine0, jstring uri1);
};

#endif // QQMLENGINEEXTENSIONPLUGIN_SHELL_H
